pygeodesy.trf.TRFXform7Tuple

Package pygeodesy :: Module trf :: Class TRFXform7Tuple |
[frames] | no frames]

# Class TRFXform7Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       TRFXform7Tuple

7-Tuple `(tx, ty, tz, s, sx, sy, sz)` of conversion parameters with translations `tx`, `ty` and `tz` in `milli-meter`, scale `s` in `ppB` and rotations `sx`, `sy` and `sz` in `milli-arc-seconds`. For `rates` all are `units-per-year`.

Note: The parameters are also named as `(Tx, Ty, Tz, D, Rx, Ry, Rz)` or `(T1, T2, T3, D, R1, R2, R3)`.

See Also: Class TransformXform's matching keyword argument names.

Instance Methods
__add__(self, other) x+y |
__eq__(self, other) x==y |
__hash__(self) hash(x) |
__mul__(self, factor) x*n |
__neg__(self) |
__sub__(self, other) |
inverse(self, name='') Return the inverse of this transform. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__contains__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| isunity Is this a `unity, identity` transform (`bool`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __add__ (self, other) (Addition operator) |
x+y Overrides: tuple.__add__ (inherited documentation)

### __eq__ (self, other) (Equality operator) |
x==y Overrides: tuple.__eq__ (inherited documentation)

### __hash__ (self) (Hashing function) |
hash(x) Overrides: object.__hash__ (inherited documentation)

### __mul__ (self, factor) |
x*n Overrides: tuple.__mul__ (inherited documentation)

### inverse (self, name='') |
Return the inverse of this transform. Arguments: `name` - Optional name (`str`). Returns: Inverse (TransformXform).

Property Details

### isunity Is this a `unity, identity` transform (`bool`). Get method: isunity(self) - Is this a `unity, identity` transform (`bool`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.